local tab = {}
tab.index = 100
tab.text = "Personal";
tab.value = "personal";



tab.populate = function()
	for i, keystone in ipairs(KeystoneRollCall.db.global.keystones) do
		if keystone and  keystone.isPlayers and keystone.name then
			local nameParts =  {strsplit("-",keystone.name or "")};
			local bestLevelLine = ""
			if keystone.bestLevel and keystone.bestDungeon then
				bestLevelLine = "+" .. KeystoneRollCall:colorLevelDifficulty(keystone.bestLevel,keystone.bestLevel).." (" .. C_ChallengeMode.GetMapInfo(keystone.bestDungeon) ..")"
			end

			tinsert(KeystoneRollCall.tableData, {
				keystone,
				KeystoneRollCall:colorFaction(nameParts[2],keystone.faction),
				KeystoneRollCall:colorClass(nameParts[1],keystone.class),
				KeystoneRollCall:colorClass(keystone.class,keystone.class),
				C_ChallengeMode.GetMapInfo(keystone.dungeon),
				keystone.level == 0 and "" or KeystoneRollCall:colorLevelDifficulty(keystone.level,keystone.level),
				bestLevelLine
			});
		end
	end
	KeystoneRollCall.scrollTable:SortData();
end

tab.setup = function(container)	
	local cols = {{
			['name'] = '',
			['width'] = 1,
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name",
		},{
			['name'] = 'Realm',
			['width'] = 65,
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "realm",
		},{
			['name'] = 'Character',
			['width'] = 85,
			['align'] = 'LEFT', 
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name",
		},{
			['name'] = 'Class',
			['width'] = 95,
			['align'] = 'LEFT',
			['field'] = "class", 
			["comparesort"] = KeystoneRollCall.columnSort,
		},{
			['name'] = 'Dungeon',
			['width'] = 160,
			['align'] = 'CENTER',
			['field'] = "dungeon",
			["comparesort"] = KeystoneRollCall.columnSort,
		},{
			['name'] = 'Level',
			['width'] = 40,
			['align'] = 'CENTER',
			['field'] = "level",
			["comparesort"] = KeystoneRollCall.columnSort,
		},{
			['name'] = "Best Run (This Week)",
			['width'] = 180,
			['field'] = "bestLevel",
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
		}
	}
	KeystoneRollCall.tableData = {};
	KeystoneRollCall.scrollTable = KeystoneRollCall.ScrollingTable:CreateST(cols,21);
	KeystoneRollCall.scrollTable:SetData(KeystoneRollCall.tableData, true);

	KeystoneRollCall.scrollTable:RegisterEvents({
		['OnClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if KeystoneRollCall.tableData and KeystoneRollCall.tableData[realrow] and KeystoneRollCall.tableData[realrow][1] then
				local keystone = KeystoneRollCall.tableData[realrow][1];
				if btn == "RightButton" then
					if UnitExists("target") and GetUnitName("target", true) then
						SendChatMessage(KeystoneRollCall:keystoneToString(keystone),"WHISPER", "COMMON",  GetUnitName("target", true));
					end
				else
					SendChatMessage(KeystoneRollCall:keystoneToString(keystone),KeystoneRollCall:getGroupChatChannel() ,  "Common")
				end
			
			end
		end,	
		['OnDoubleClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if KeystoneRollCall.tableData and KeystoneRollCall.tableData[realrow] and  KeystoneRollCall.tableData[realrow][1] then
				local keystone = KeystoneRollCall.tableData[realrow][1];
				SendChatMessage(KeystoneRollCall:keystoneToString(keystone),"GUILD" ,  "Common")
			end
		end,	
		['OnEnter'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			if KeystoneRollCall.tableData and KeystoneRollCall.tableData[realrow] and  KeystoneRollCall.tableData[realrow][1] then
				KeystoneRollCall.frame:SetStatusText("Left Click: Send to Party   -   Double Click: Send to Guild   -   Right Click: Send to Target")
			end
		end,
		['OnLeave'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			KeystoneRollCall.frame:SetStatusText("")
		end,
	});
	
	local tableWrapper = KeystoneRollCall.AceGUI:Create('lib-st'):WrapST(KeystoneRollCall.scrollTable);
	tableWrapper.head_offset = 15;
	container:AddChild(tableWrapper);
	
	local spacer = KeystoneRollCall.AceGUI:Create('Heading');
	spacer:SetFullWidth(true);
	spacer:SetText(' ');
	container:AddChild(spacer);
	
	local broadcastPartyButton = KeystoneRollCall.AceGUI:Create('Button');
	broadcastPartyButton:SetWidth(200);
	broadcastPartyButton:SetText('Broadcast All to Party/Raid');

	broadcastPartyButton:SetCallback('OnClick', function()
		KeystoneRollCall:ReportAvailableKeys(KeystoneRollCall:getGroupChatChannel() );
	end);
	container:AddChild(broadcastPartyButton);
	
	local broadcastGuildButton = KeystoneRollCall.AceGUI:Create('Button');
	broadcastGuildButton:SetWidth(200);
	broadcastGuildButton:SetText('Broadcast All to Guild');

	broadcastGuildButton:SetCallback('OnClick', function()
		KeystoneRollCall:ReportAvailableKeys("GUILD");
	end);
	container:AddChild(broadcastGuildButton);
	
	local whisperTargetButton = KeystoneRollCall.AceGUI:Create('Button');
	whisperTargetButton:SetWidth(200);
	whisperTargetButton:SetText('Whisper All to Target');

	whisperTargetButton:SetCallback('OnClick', function()
		local name = UnitName("target")
		if name then
			KeystoneRollCall:ReportAvailableKeys("WHISPER",name);
		end
	end);
	container:AddChild(whisperTargetButton);
end

KeystoneRollCall.tabs[tab.value] = tab;